Class: Weechat::Window
- Inherits:
-
Object
- Object
- Weechat::Window
- Extended by:
- Properties
- Includes:
- Pointer
- Defined in:
- lib/weechat/window.rb
Overview
Gettable properties
- buffer
-
The buffer currently shown in the window
- x
-
X position of the window in the terminal
- y
-
Y position of the window in the terminal
- width
-
Width of the window
- height
-
Height of the window
- width_pct
-
Width relative to the one of the parent window (0..100%)
- height_pct
-
Height relative to the one of the parent window (0..100%)
- first_line_displayed?
-
True if the first line of the displayed buffer is displayed on the screen
- scrolling?
-
True if the window is currently being scrolled
- scrolling_lines
-
Number of lines that are not being displayed (in the bottom direction)
The chat area
See Chat
Defined Under Namespace
Classes: Chat
Instance Attribute Summary collapse
-
#chat ⇒ Object
readonly
Returns the value of attribute chat.
Attributes included from Pointer
Class Method Summary collapse
Methods included from Properties::ClassMethods
#all, #apply_rtransformation, #apply_transformation, #init_properties, #known_integer_properties, #known_properties, #known_string_properties, #mappings, #rtransformations, #settable_properties, #transformations, #type
Methods included from Pointer
#==, #hash, included, #inspect, #to_s
Instance Attribute Details
#chat ⇒ Object (readonly)
Returns the value of attribute chat.
93 94 95 |
# File 'lib/weechat/window.rb', line 93 def chat @chat end |
Class Method Details
.current ⇒ Object
80 81 82 |
# File 'lib/weechat/window.rb', line 80 def current Window.from_ptr(Weechat.current_window) end |
.from_ptr(*args) ⇒ Object
84 85 86 87 88 |
# File 'lib/weechat/window.rb', line 84 def from_ptr(*args) o = super o.instance_variable_set(:@chat, Chat.new(o)) o end |